==> zio-aws-macie2_2.12-5.17.116.1-sources.jar: zio/aws/macie2/model/IamUser.scala <==
package zio.aws.macie2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.macie2.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class IamUser(
    accountId: Option[__string] = None,
    arn: Option[__string] = None,
    principalId: Option[__string] = None,
    userName: Option[__string] = None
) {
  def buildAwsValue(): software.amazon.awssdk.services.macie2.model.IamUser = {
    import IamUser.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.IamUser
      .builder()
      .optionallyWith(
        accountId.map(value => __string.unwrap(value): java.lang.String)
      )(_.accountId)
      .optionallyWith(
        arn.map(value => __string.unwrap(value): java.lang.String)
      )(_.arn)
      .optionallyWith(
        principalId.map(value => __string.unwrap(value): java.lang.String)
      )(_.principalId)
      .optionallyWith(
        userName.map(value => __string.unwrap(value): java.lang.String)
      )(_.userName)
      .build()
  }
  def asReadOnly: zio.aws.macie2.model.IamUser.ReadOnly =
    zio.aws.macie2.model.IamUser.wrap(buildAwsValue())
}
object IamUser {
  private lazy val zioAwsBuilderHelper
      : BuilderHelper[software.amazon.awssdk.services.macie2.model.IamUser] =
    BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.macie2.model.IamUser = zio.aws.macie2.model.IamUser(
      accountId.map(value => value),
      arn.map(value => value),
      principalId.map(value => value),
      userName.map(value => value)
    )
    def accountId: Option[__string]
    def arn: Option[__string]
    def principalId: Option[__string]
    def userName: Option[__string]
    def getAccountId: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("accountId", accountId)
    def getArn: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("arn", arn)
    def getPrincipalId: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("principalId", principalId)
    def getUserName: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("userName", userName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.IamUser
  ) extends zio.aws.macie2.model.IamUser.ReadOnly {
    override val accountId: Option[__string] = scala
      .Option(impl.accountId())
      .map(value => zio.aws.macie2.model.primitives.__string(value))
    override val arn: Option[__string] = scala
      .Option(impl.arn())
      .map(value => zio.aws.macie2.model.primitives.__string(value))
    override val principalId: Option[__string] = scala
      .Option(impl.principalId())
      .map(value => zio.aws.macie2.model.primitives.__string(value))
    override val userName: Option[__string] = scala
      .Option(impl.userName())
      .map(value => zio.aws.macie2.model.primitives.__string(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.IamUser
  ): zio.aws.macie2.model.IamUser.ReadOnly = new Wrapper(impl)
}

==> zio-aws-macie2_2.12-5.17.149.1-sources.jar: zio/aws/macie2/model/IamUser.scala <==
package zio.aws.macie2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.macie2.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class IamUser(
    accountId: Option[__string] = None,
    arn: Option[__string] = None,
    principalId: Option[__string] = None,
    userName: Option[__string] = None
) {
  def buildAwsValue(): software.amazon.awssdk.services.macie2.model.IamUser = {
    import IamUser.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.IamUser
      .builder()
      .optionallyWith(accountId.map(value => value: java.lang.String))(
        _.accountId
      )
      .optionallyWith(arn.map(value => value: java.lang.String))(_.arn)
      .optionallyWith(principalId.map(value => value: java.lang.String))(
        _.principalId
      )
      .optionallyWith(userName.map(value => value: java.lang.String))(
        _.userName
      )
      .build()
  }
  def asReadOnly: zio.aws.macie2.model.IamUser.ReadOnly =
    zio.aws.macie2.model.IamUser.wrap(buildAwsValue())
}
object IamUser {
  private lazy val zioAwsBuilderHelper
      : BuilderHelper[software.amazon.awssdk.services.macie2.model.IamUser] =
    BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.macie2.model.IamUser = zio.aws.macie2.model.IamUser(
      accountId.map(value => value),
      arn.map(value => value),
      principalId.map(value => value),
      userName.map(value => value)
    )
    def accountId: Option[__string]
    def arn: Option[__string]
    def principalId: Option[__string]
    def userName: Option[__string]
    def getAccountId: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("accountId", accountId)
    def getArn: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("arn", arn)
    def getPrincipalId: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("principalId", principalId)
    def getUserName: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("userName", userName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.IamUser
  ) extends zio.aws.macie2.model.IamUser.ReadOnly {
    override val accountId: Option[__string] =
      scala.Option(impl.accountId()).map(value => value: __string)
    override val arn: Option[__string] =
      scala.Option(impl.arn()).map(value => value: __string)
    override val principalId: Option[__string] =
      scala.Option(impl.principalId()).map(value => value: __string)
    override val userName: Option[__string] =
      scala.Option(impl.userName()).map(value => value: __string)
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.IamUser
  ): zio.aws.macie2.model.IamUser.ReadOnly = new Wrapper(impl)
}
